==> egroupware_1.0.0.007-2.dfsg.orig.tar.gz: egroupware-1.0.0.007-2.dfsg/phpsysinfo/includes/lang/es.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: es.php,v 1.2 2004/01/20 20:57:47 reinerj Exp $

$text['title']          = 'Informaci&oacute;n Del Sistema';

$text['vitals']         = 'Vitales';
$text['hostname']       = 'Nombre Del Sistema';
$text['ip']             = 'Direcci&oacute;n IP';
$text['kversion']       = 'Versi&oacute;n Del N&uacute;cleo';
$text['uptime']         = 'Uptime';
$text['users']          = 'Usuarios Actuales';
$text['loadavg']        = 'Promedio De Uso';

$text['hardware']       = 'Informaci&oacute;n Del Hardware';
$text['numcpu']         = 'Procesadores';
$text['cpumodel']       = 'Modelo';
$text['mhz']            = 'Frecuencia';
$text['cache']          = 'Tama&ntilde;o Del Cach&eacute;';
$text['bogomips']       = 'Bogomips';
$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';

$text['netusage']       = 'Utilizaci&oacute;n De La Red';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recibidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Errores/Perdidos';

$text['memusage']       = 'Utilizaci&oacute;n De La Memoria';
$text['phymem']         = 'Memoria F&iacute;sica';
$text['swap']           = 'Memoria De Intercambio';

$text['fs']             = 'Sistemas De Archivos';
$text['mount']          = 'Punto De Montaje';
$text['partition']      = 'Partici&oacute;n';

$text['percent']        = 'Porcentaje De Uso';
$text['type']           = 'Tipo';
$text['free']           = 'Libre';
$text['used']           = 'Usado';
$text['size']           = 'Tama&ntilde;o';
$text['totals']         = 'Totales';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ninguno';

$text['capacity']       = 'Capacidad';

$text['template']       = 'Plantilla';
$text['language']       = 'Idioma';
$text['submit']         = 'Enviar';
$text['created']        = 'Creado por';

$text['days']           = 'd&iacute;as';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';
?>

==> egroupware_1.2.107-2.dfsg.orig.tar.gz: egroupware-1.2.107-2.dfsg/phpsysinfo/includes/lang/es.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: es.php 21228 2006-04-06 13:52:08Z ralfbecker $

$text['title']          = 'Informaci&oacute;n Del Sistema';

$text['vitals']         = 'Vitales';
$text['hostname']       = 'Nombre Del Sistema';
$text['ip']             = 'Direcci&oacute;n IP';
$text['kversion']       = 'Versi&oacute;n Del N&uacute;cleo';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Usuarios Actuales';
$text['loadavg']        = 'Promedio De Uso';

$text['hardware']       = 'Informaci&oacute;n Del Hardware';
$text['numcpu']         = 'Procesadores';
$text['cpumodel']       = 'Modelo';
$text['cpuspeed']       = 'Frecuencia';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tama&ntilde;o Del Cach&eacute;';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';
$text['usb']            = 'Dispositivos USB';

$text['netusage']       = 'Utilizaci&oacute;n De La Red';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recibidos';
$text['sent']           = 'Enviados';
$text['errors']         = 'Errores/Perdidos';

$text['memusage']       = 'Utilizaci&oacute;n De La Memoria';
$text['phymem']         = 'Memoria F&iacute;sica';
$text['swap']           = 'Memoria De Intercambio';

$text['fs']             = 'Sistemas De Archivos';
$text['mount']          = 'Punto De Montaje';
$text['partition']      = 'Partici&oacute;n';

$text['percent']        = 'Porcentaje De Uso';
$text['type']           = 'Tipo';
$text['free']           = 'Libre';
$text['used']           = 'Usado';
$text['size']           = 'Tama&ntilde;o';
$text['totals']         = 'Totales';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ninguno';

$text['capacity']       = 'Capacidad';

$text['template']       = 'Plantilla';
$text['language']       = 'Idioma';
$text['submit']         = 'Enviar';
$text['created']        = 'Creado por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'd&iacute;as';
$text['hours']          = 'horas';
$text['minutes']        = 'minutos';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
